@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (c) 2016-2023 VMware, Inc. All rights reserved.
+ * Copyright (c) 2016-2024 Broadcom. All rights reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -48,6 +49,33 @@
 #include "certverify.h"
 #include "vmxlog.h"
 
+/*
+ * XXX
+ *
+ * Optimization idea: stash a hash (SHA512) of a valid token, and bypass
+ * the full assertion process when we see that token again. The expiration
+ * date of the token must also be saved off (and beware the time skew issue).
+ *
+ * Note that there's some extra complexity here:
+ *
+ * 1 - AddAlias sets up a cert/user mapping
+ * 2 - a SAML token is used (and cached) using this cert/user combo
+ * 3 - RemoveAlias removes the combo
+ * 4 - the cached token still works
+ *
+ * So the cache should only bypass the token validation, not the certificate
+ * check in ServiceVerifyAndCheckTrustCertChainForSubject()
+ *
+ * Also TBD is how much this buys us in the real world.  With short
+ * token lifetimes, its less interesting.  Its also possible that
+ * it will have no measureable affect because the token verification
+ * will be lost in the noise of the API plumbing from VC->hostd->VMX->tools.
+ *
+ * The security folks have signed off on this, so long as we store only
+ * in memory.
+ *
+ */
+
 static int gClockSkewAdjustment = VGAUTH_PREF_DEFAULT_CLOCK_SKEW_SECS;
 static gboolean gAllowUnrelatedCerts = FALSE;
 static xmlSchemaPtr gParsedSchemas = NULL;
@@ -404,14 +432,6 @@ SAML_Init(void)
     */
    LIBXML_TEST_VERSION
 
-   /*
-    * Tell libxml to do ID/REF lookups
-    * Tell libxml to complete attributes with defaults from the DTDs
-    */
-   xmlLoadExtDtdDefaultValue = XML_DETECT_IDS | XML_COMPLETE_ATTRS;
-   xmlSubstituteEntitiesDefault(1);
-
-
    /* set up the xml2 error handler */
    xmlSetGenericErrorFunc(NULL, XmlErrorHandler);
 
@@ -1195,6 +1215,7 @@ BuildCertChain(xmlNodePtr x509Node,
       /*
        * Add cert to the keymanager.
        */
+      /* coverity[string_null] */
       ret = xmlSecCryptoAppKeysMngrCertLoadMemory(mgr,
                                                   pemCert,
                                                   (xmlSecSize) strlen(pemCert),
@@ -1321,9 +1342,9 @@ VerifySignature(xmlDocPtr doc,
    /*
     * Get the cert chain from the token.
     *
-    * Unlike xml-security-c, xmlsec1 wants to validate the cert
-    * chain in the token so it needs the full chain, not just
-    * the public key from the first cert.
+    * xmlsec1 wants to validate the cert chain in the token
+    * so it needs the full chain, not just the public key from
+    * the first cert.
     *
     * Also save it off for later use by the alias store check.
     */
@@ -1383,8 +1404,8 @@ VerifySignature(xmlDocPtr doc,
    }
 
    /*
-    * The xml-security-c verifies the Reference explicitly; this
-    * isn't needed for xmlsec1 because the library does it.
+    * No need to verify the Reference explicitly because the
+    * xmlsec1 library takes care of it.
     */
 
    /*
@@ -1395,9 +1416,10 @@ VerifySignature(xmlDocPtr doc,
     * dsigCtx->status can be at the wrong offset.  So
     * dump the value of status, which should be either
     * 1 (xmlSecDSigStatusSucceeded) or 2 (xmlSecDSigStatusInvalid).
-    * If its something else, that's a sign there's a
-    * build issue and XMLSEC_NO_SIZE_T may be set at one layer but
-    * not the other.
+    * If its something else, that could be a sign that there's a build issue
+    * and that libxmlsec1 is using a different size type than its callers.
+    * Please see xmlSecSize changelog in
+    * https://www.aleksey.com/xmlsec/news.html
     *
     */
    if (dsigCtx->status != xmlSecDSigStatusSucceeded) {
@@ -1494,7 +1516,13 @@ VerifySAMLToken(const gchar *token,
                            strlen(token),
                            NULL, NULL, 0);
 #else
-   doc = xmlParseMemory(token, (int)strlen(token));
+   /*
+    * Tell libxml to substitute the entities (XML_PARSE_NOENT).
+    * Tell libxml to load the external DTD (XML_PARSE_DTDLOAD).
+    * Tell libxml to add default attributes from the DTD (XML_PARSE_DTDATTR).
+    */
+   doc = xmlReadMemory(token, (int)strlen(token), NULL, NULL,
+                       XML_PARSE_NOENT | XML_PARSE_DTDATTR | XML_PARSE_DTDLOAD);
 #endif
    if ((NULL == doc) || (xmlDocGetRootElement(doc) == NULL)) {
       g_warning("Failed to parse document\n");
@@ -1707,6 +1735,7 @@ SAML_VerifyBearerTokenAndChain(const char *xmlText,
       if (err != VGAUTH_E_OK) {
          VMXLog_Log(VMXLOG_LEVEL_WARNING,
                     "Unrelated certs found in SAML token, failing\n");
+         FreeCertArray(num, certChain);
          return VGAUTH_E_AUTHENTICATION_DENIED;
       }
    }
